EPHYS-ANONYMIZER
================

Use this to anonymize faces and electrophysiology data. Please cite the github repository if you do.

There is absolutely no warrenty that this will correctly remove faces from all video frames or all data from files. You must check all the videos and data to be sure they are anonymized.

INSTALLATION
============

Install Python (using Conda https://docs.conda.io/en/latest/ or not https://www.python.org/)
In a terminal type ``pip install ephys-anonymizer``.
You're ready to go! Try it out using ``video_anonymize path/to/my/video``.

Alex Rockhill
Eugene, OR 2020